@@ -1,11 +1,11 @@
 import threading
 
-import sys
+import sys, os
 import traceback
-
 import time
-
 import logging
+import socket
+import errno
 
 from whatap.io import DataOutputX
 from whatap.net.packet_enum import PacketEnum
@@ -18,23 +18,22 @@ class UdpSession(object):
     s = None
     buffer_arr = []
     thread_lock = threading.Lock()
+    read_timeout = 5
 
     @classmethod
     def udp(cls):
-        import socket
+        import socket, struct
         sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         sock.setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, PacketEnum.PACKET_SEND_BUFFER_SIZE)
         sock.connect((PacketEnum.SERVER, PacketEnum.PORT))
         cls.s = sock
-
-        t = threading.Thread(target=cls.get)
-        t.setDaemon(True)
-        t.start()
+        sock.settimeout(cls.read_timeout)
 
         return sock
 
     @classmethod
     def send_packet(cls, packet_type, ctx, datas=[]):
+        import whatap.net.udp_thread
         try:
             if len(b''.join(cls.buffer_arr)) > PacketEnum.PACKET_BUFFER_SIZE:
                 cls.send(packet_type, ctx)
@@ -59,6 +58,7 @@ class UdpSession(object):
                 dout.writeInt(ctx.elapsed)
                 dout.writeLong(ctx.getCpuTime())
                 dout.writeLong(ctx.getMemory())
+                dout.writeInt(os.getpid())
                 dout.writeLong(ctx.thread_id)
 
             diff = PacketEnum.PACKET_BUFFER_SIZE \
@@ -110,18 +110,20 @@ class UdpSession(object):
         finally:
             cls.buffer_arr = []
             if packet_type == PacketTypeEnum.TX_END:
-                TraceContextManager.end(ctx.id)
+                TraceContextManager.end(ctx.thread_id)
 
     @classmethod
     def get(cls):
-        while True:
-            try:
-                received = cls.s.recv(1024)
+        from whatap.conf.configure import Configure as conf
+        try:
+            received = cls.s.recv(1024)
+            if received:
                 cls.handle(received.decode().split(','))
-                time.sleep(1)
-            except Exception as e:
-                print('get stack ', e)
-                logging.debug(e, extra={'id': 'WA914'}, exc_info=True)
+        except socket.error as serr:
+            if serr.errno == errno.EAGAIN:
+                conf.init(display=False)
+            else:
+                raise serr
 
     @classmethod
     def handle(cls, received):
@@ -180,5 +182,10 @@ class UdpSession(object):
                     data += '{} ({}:{})\n'.format(method_name, line, line_num)
 
                 datas.append(data)
+            elif param_id == ParamDef.GET_ACTIVE_STATS:
+                stats = TraceContextManager.getActiveStats()
+                datas = [','.join([str(x) for x in stats])]
+                cls.send_packet(PacketTypeEnum.ACTIVE_STATS, None, datas)
+                return
 
             cls.send_packet(PacketTypeEnum.TX_PARAM, None, datas)
