@@ -33,6 +33,7 @@ def trace_handler(fn, start=False):
                 callback = func(*args, **kwargs)
             except Exception as e:
                 logging.debug(e, extra={'id': 'WA917'}, exc_info=True)
+                print(e, dict(extra={'id': 'WA917'}, exc_info=True))
                 return fn(*args, **kwargs)
             else:
                 return callback
@@ -46,6 +47,7 @@ def start_interceptor(ctx):
     if conf.dev:
         logging.debug('start transaction id(seq): {}'.format(ctx.id),
                       extra={'id': 'WA111'})
+        print('start transaction id(seq): {}'.format(ctx.id),dict(extra={'id': 'WA111'}))
     
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
@@ -71,6 +73,8 @@ def end_interceptor(thread_id=None):
     if conf.dev:
         logging.debug('end   transaction id(seq): {}'.format(ctx.id),
                       extra={'id': 'WA112'})
+        print('end   transaction id(seq): {}'.format(ctx.id),
+                      dict(extra={'id': 'WA112'}))
     
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
@@ -158,6 +162,7 @@ def interceptor(rn_environ, *args, **kwargs):
 
 
 def interceptor_error(status_code, errors):
+    print('error', status_code, errors)
     ctx = TraceContextManager.getLocalContext()
     ctx.status = int(status_code / 100)
     if ctx.status >= 4 and not ctx.error:
@@ -185,6 +190,7 @@ def interceptor_error(status_code, errors):
 
 
 def interceptor_step_error(e):
+    print('interceptor_step_error', e)
     ctx = TraceContextManager.getLocalContext()
     ctx.error_step = e
     if not ctx.error:
@@ -238,6 +244,7 @@ def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
         return callback
     except Exception as e:
         interceptor_step_error(e)
+        print('interceptor_httpc_request', e)
     finally:
         datas = [ctx.httpc_url, ctx.mcallee]
         ctx.elapsed = DateUtil.nowSystem() - start_time
@@ -256,6 +263,20 @@ def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
         ctx.active_httpc_hash = 0
         ctx.httpc_url = None
 
+def interceptor_sock_connect(fn, *args, **kwargs):
+    ctx = TraceContextManager.getLocalContext()
+    if not ctx :
+        return fn(*args, **kwargs)
+
+    try:
+        ctx.socket_connecting = True
+        callback = fn(*args, **kwargs)
+        return callback
+    except Exception as e:
+        interceptor_step_error(e)
+        print('interceptor_sock_connect', e)
+    finally:
+        ctx.socket_connecting = False
 
 def interceptor_db_con(fn, db_type, *args, **kwargs):
     ctx = TraceContextManager.getLocalContext()
@@ -264,9 +285,14 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
     
     start_time = DateUtil.nowSystem()
     ctx.start_time = start_time
-    
-    callback = fn(*args, **kwargs)
-    
+
+    ctx.db_opening = True
+    try:
+        callback = fn(*args, **kwargs)
+    finally:
+
+        ctx.db_opening = False
+
     if not kwargs:
         kwargs = dict(
             x.split('=') for x in re.sub(r'\s*=\s*', '=', args[0]).split())
@@ -281,9 +307,7 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
     ctx.lctx['dbc'] = text
     
     ctx.active_dbc = 0
-    
-    ctx.db_opening = True
-    
+
     datas = [text]
     ctx.elapsed = DateUtil.nowSystem() - start_time
     UdpSession.send_packet(PacketTypeEnum.TX_DB_CONN, ctx, datas)
@@ -312,6 +336,7 @@ def interceptor_db_execute(fn, *args, **kwargs):
         return callback
     except Exception as e:
         interceptor_step_error(e)
+        print('interceptor_db_execute', e)
     finally:
         datas = [ctx.lctx.get('dbc', ''), query]
         ctx.elapsed = DateUtil.nowSystem() - start_time
